@@ -50,6 +50,7 @@ mod function;
 mod lua;
 mod multi;
 mod scope;
+mod stdlib;
 mod string;
 mod table;
 mod thread;
@@ -65,6 +66,7 @@ pub use crate::function::Function;
 pub use crate::lua::{Chunk, Lua};
 pub use crate::multi::Variadic;
 pub use crate::scope::Scope;
+pub use crate::stdlib::StdLib;
 pub use crate::string::String;
 pub use crate::table::{Table, TablePairs, TableSequence};
 pub use crate::thread::{Thread, ThreadStatus};
