@@ -1,14 +1,3 @@
-#![cfg_attr(
-    all(feature = "luajit", target_os = "macos", target_arch = "x86_64"),
-    feature(link_args)
-)]
-
-#[cfg_attr(
-    all(feature = "luajit", target_os = "macos", target_arch = "x86_64"),
-    link_args = "-pagezero_size 10000 -image_base 100000000"
-)]
-extern "system" {}
-
 use std::iter::FromIterator;
 use std::panic::catch_unwind;
 use std::sync::Arc;
@@ -92,13 +81,13 @@ fn test_lua_multi() -> Result<()> {
 
     lua.load(
         r#"
-            function concat(arg1, arg2)
-                return arg1 .. arg2
-            end
+        function concat(arg1, arg2)
+            return arg1 .. arg2
+        end
 
-            function mreturn()
-                return 1, 2, 3, 4, 5, 6
-            end
+        function mreturn()
+            return 1, 2, 3, 4, 5, 6
+        end
     "#,
     )
     .exec()?;
