@@ -1,19 +1,8 @@
-#![cfg_attr(
-    all(feature = "luajit", target_os = "macos", target_arch = "x86_64"),
-    feature(link_args)
-)]
-
-#[cfg_attr(
-    all(feature = "luajit", target_os = "macos", target_arch = "x86_64"),
-    link_args = "-pagezero_size 10000 -image_base 100000000"
-)]
-extern "system" {}
-
 use std::sync::Arc;
 
 use mlua::{
     AnyUserData, ExternalError, Function, Lua, MetaMethod, Result, String, UserData,
-    UserDataMethods,
+    UserDataMethods, Value,
 };
 
 #[test]
@@ -96,6 +85,9 @@ fn test_metamethods() -> Result<()> {
                 MetaMethod::Sub,
                 |_, (lhs, rhs): (MyUserData, MyUserData)| Ok(MyUserData(lhs.0 - rhs.0)),
             );
+            methods.add_meta_function(MetaMethod::Eq, |_, (lhs, rhs): (MyUserData, MyUserData)| {
+                Ok(lhs.0 == rhs.0)
+            });
             methods.add_meta_method(MetaMethod::Index, |_, data, index: String| {
                 if index.to_str()? == "inner" {
                     Ok(data.0)
@@ -104,7 +96,7 @@ fn test_metamethods() -> Result<()> {
                 }
             });
             #[cfg(any(feature = "lua53", feature = "lua52"))]
-            methods.add_meta_method(MetaMethod::IPairs, |lua, data, ()| {
+            methods.add_meta_method(MetaMethod::Pairs, |lua, data, ()| {
                 use std::iter::FromIterator;
                 let stateless_iter = lua.create_function(|_, (data, i): (MyUserData, i64)| {
                     let i = i + 1;
@@ -122,18 +114,19 @@ fn test_metamethods() -> Result<()> {
     let globals = lua.globals();
     globals.set("userdata1", MyUserData(7))?;
     globals.set("userdata2", MyUserData(3))?;
+    globals.set("userdata3", MyUserData(3))?;
     assert_eq!(
         lua.load("userdata1 + userdata2").eval::<MyUserData>()?.0,
         10
     );
 
     #[cfg(any(feature = "lua53", feature = "lua52"))]
-    let ipairs_it = {
+    let pairs_it = {
         lua.load(
             r#"
-            function ipairs_it()
+            function pairs_it()
                 local r = 0
-                for i, v in ipairs(userdata1) do
+                for i, v in pairs(userdata1) do
                     r = r + v
                 end
                 return r
@@ -141,16 +134,23 @@ fn test_metamethods() -> Result<()> {
         "#,
         )
         .exec()?;
-        globals.get::<_, Function>("ipairs_it")?
+        globals.get::<_, Function>("pairs_it")?
     };
 
     assert_eq!(lua.load("userdata1 - userdata2").eval::<MyUserData>()?.0, 4);
     assert_eq!(lua.load("userdata1:get()").eval::<i64>()?, 7);
     assert_eq!(lua.load("userdata2.inner").eval::<i64>()?, 3);
     #[cfg(any(feature = "lua53", feature = "lua52"))]
-    assert_eq!(ipairs_it.call::<_, i64>(())?, 28);
+    assert_eq!(pairs_it.call::<_, i64>(())?, 28);
     assert!(lua.load("userdata2.nonexist_field").eval::<()>().is_err());
 
+    let userdata2: Value = globals.get("userdata2")?;
+    let userdata3: Value = globals.get("userdata3")?;
+
+    assert!(lua.load("userdata2 == userdata3").eval::<bool>()?);
+    assert!(userdata2 != userdata3); // because references are differ
+    assert!(userdata2.equals(userdata3)?);
+
     Ok(())
 }
 
@@ -175,18 +175,18 @@ fn test_gc_userdata() -> Result<()> {
     assert!(lua
         .load(
             r#"
-        local tbl = setmetatable({
-            userdata = userdata
-        }, { __gc = function(self)
-            -- resurrect userdata
-            hatch = self.userdata
-        end })
+            local tbl = setmetatable({
+                userdata = userdata
+            }, { __gc = function(self)
+                -- resurrect userdata
+                hatch = self.userdata
+            end })
 
-        tbl = nil
-        userdata = nil  -- make table and userdata collectable
-        collectgarbage("collect")
-        hatch:access()
-    "#
+            tbl = nil
+            userdata = nil  -- make table and userdata collectable
+            collectgarbage("collect")
+            hatch:access()
+        "#
         )
         .exec()
         .is_err());
